@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} cot (@var{X})
 ## 
 ## Compute the cotangent in radians, that is the reciprocal tangent.
@@ -53,6 +53,9 @@ possiblynotfullperiod = not (certainlyfullperiod);
 l (possiblynotfullperiod) = mpfr_function_d ('cot', -inf, x.sup (possiblynotfullperiod));
 u (possiblynotfullperiod) = mpfr_function_d ('cot', inf, x.inf (possiblynotfullperiod));
 
+l (x.sup == 0) = -inf;
+u (x.inf == 0) = +inf;
+
 singularity = certainlyfullperiod | ...
               l > u | (...
                   width > 2 & (...
