@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} log1p (@var{X})
 ## 
 ## Compute @code{log (1 + @var{X})} accurately in the neighborhood of zero.
