@@ -24,7 +24,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} {} @var{X} \ @var{Y}
 ## 
 ## Return the interval matrix left division of @var{X} and @var{Y}.
@@ -35,6 +35,7 @@
 ## @group
 ## infsup ([1, 0; 0, 2]) \ [2, 0; 0, 4]
 ##   @result{} 2×2 interval matrix
+##
 ##      [2]   [0]
 ##      [0]   [2]
 ## @end group
