@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} {} @var{X} / @var{Y}
 ## 
 ## Return the interval matrix right division of @var{X} and @var{Y}.
@@ -25,6 +25,7 @@
 ## @group
 ## infsup ([1, 2; 3, 4]) / [3, 4; 1, 2]
 ##   @result{} 2×2 interval matrix
+##
 ##      [0]   [1]
 ##      [1]   [0]
 ## @end group
