@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} {} @var{X} * @var{Y}
 ## @deftypefnx {Function File} {} mtimes (@var{X}, @var{Y})
 ## @deftypefnx {Function File} {} mtimes (@var{X}, @var{Y}, @var{ACCURACY})
@@ -35,6 +35,7 @@
 ## y = infsup ([3, 3; 0, 1], [3, 3.25; 0, 2]);
 ## x * y
 ##   @result{} 2×2 interval matrix
+##
 ##          [3, 6]      [5, 10.5]
 ##      [21, 22.5]   [36, 54.375]
 ## @end group
