@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {@var{X} =} powrev1 (@var{B}, @var{C}, @var{X})
 ## @deftypefnx {Function File} {@var{X} =} powrev1 (@var{B}, @var{C})
 ## 
