@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} {} @var{A} (@var{I})
 ## @deftypefnx {Function File} {} {} @var{A} (@var{I1}, @var{I2})
 ## @deftypefnx {Function File} {} {} @var{A}.@var{P}
@@ -33,6 +33,7 @@
 ##   @result{} [8, 9]
 ## x (:, 2)
 ##   @result{} 3×1 interval vector
+##
 ##       [1, 2]
 ##       [5, 6]
 ##      [9, 10]
