@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} {} [@var{ARRAY1}; @var{ARRAY2}; ...]
 ##
 ## Return the vertical concatenation of interval array objects along
@@ -40,18 +40,16 @@
 
 function result = vertcat (varargin)
 
-l = u = cell (nargin, 1);
+varargin = transpose (varargin);
 
-for i = 1 : nargin
-    if (not (isa (varargin {i}, "infsup")))
-        varargin {i} = infsup (varargin {i});
-    endif
-    l {i} = inf (varargin {i});
-    u {i} = sup (varargin {i});
-endfor
+## Conversion to interval
+intervals = cellfun ("isclass", varargin, "infsup");
+to_convert = not (intervals);
+varargin (to_convert) = cellfun (@infsup, varargin (to_convert), ...
+                                 "UniformOutput", false ());
 
-l = cell2mat (l);
-u = cell2mat (u);
+l = cell2mat (cellfun (@(x) x.inf, varargin, "UniformOutput", false ()));
+u = cell2mat (cellfun (@(x) x.sup, varargin, "UniformOutput", false ()));
 
 result = infsup (l, u);
 
