@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} abs (@var{X})
 ## 
 ## Compute the absolute value of numbers.
@@ -50,7 +50,7 @@ endif
 
 result = newdec (abs (intervalpart (x)));
 ## abs is defined and continuous everywhere
-result.dec = mindec (result.dec, x.dec);
+result.dec = min (result.dec, x.dec);
 
 endfunction
 
