@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} csc (@var{X})
 ## 
 ## Compute the cosecant in radians, that is the reciprocal sine.
@@ -47,12 +47,12 @@ if (isnai (x))
 endif
 
 result = newdec (csc (intervalpart (x)));
-result.dec = mindec (result.dec, x.dec);
+result.dec = min (result.dec, x.dec);
 
 ## Because csc (nextdown (pi)) < realmax, we can simple check for
 ## a singularity by comparing the result with entire for x ~= 0.
 domain = not (isentire (result)) | (inf (x) <= 0 & sup (x) >= 0);
-result.dec (not (domain)) = "trv";
+result.dec (not (domain)) = _trv ();
 
 endfunction
 
