@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} csch (@var{X})
 ## 
 ## Compute the hyperbolic cosecant, that is the reciprocal hyperbolic sine.
@@ -48,8 +48,8 @@ endif
 
 result = newdec (csch (intervalpart (x)));
 ## csch is defined and continuous for x ~= 0
-result.dec = mindec (result.dec, x.dec);
-result.dec (inf (x) <= 0 & sup (x) >= 0) = "trv";
+result.dec = min (result.dec, x.dec);
+result.dec (inf (x) <= 0 & sup (x) >= 0) = _trv ();
 
 endfunction
 
