@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} dilog (@var{X})
 ## 
 ## Compute the real part of the dilogarithm function.
@@ -64,7 +64,7 @@ endif
 
 result = newdec (dilog (intervalpart (x)));
 ## dilog is defined and continuous everywhere
-result.dec = mindec (result.dec, x.dec);
+result.dec = min (result.dec, x.dec);
 
 endfunction
 
