@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} ei (@var{X})
 ## 
 ## Compute the exponential integral for positive arguments.
@@ -63,10 +63,10 @@ if (isnai (x))
 endif
 
 result = newdec (ei (intervalpart (x)));
-result.dec = mindec (result.dec, x.dec);
+result.dec = min (result.dec, x.dec);
 
 ## ei is continuous everywhere, but defined for x > 0 only
-result.dec (not (interior (x, infsupdec (0, inf)))) = "trv";
+result.dec (not (interior (x, infsupdec (0, inf)))) = _trv ();
 
 endfunction
 
