@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} erfc (@var{X})
 ## 
 ## Compute the complementary error function.
@@ -65,7 +65,7 @@ endif
 
 result = newdec (erfc (intervalpart (x)));
 ## erfc is defined and continuous everywhere
-result.dec = mindec (result.dec, x.dec);
+result.dec = min (result.dec, x.dec);
 
 endfunction
 
