@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} expm1 (@var{X})
 ## 
 ## Compute @code{exp (@var{X} - 1)} accurately in the neighborhood of zero.
@@ -48,7 +48,7 @@ endif
 
 result = newdec (expm1 (intervalpart (x)));
 ## expm1 is defined and continuous everywhere
-result.dec = mindec (result.dec, x.dec);
+result.dec = min (result.dec, x.dec);
 
 endfunction
 
