@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} fma (@var{X}, @var{Y}, @var{Z})
 ## 
 ## Fused multiply and add @code{@var{X} * @var{Y} + @var{Z}}.
@@ -73,7 +73,7 @@ endif
 result = newdec (...
         fma (intervalpart (x), intervalpart (y), intervalpart (z)));
 ## fma is defined and continuous everywhere
-result.dec = mindec (result.dec, x.dec, y.dec, z.dec);
+result.dec = min (result.dec, min (x.dec, min (y.dec, z.dec)));
 
 endfunction
 
