@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} gammaln (@var{X})
 ## 
 ## Compute the logarithm of the gamma function for positive arguments.
@@ -64,10 +64,10 @@ if (isnai (x))
 endif
 
 result = newdec (gammaln (intervalpart (x)));
-result.dec = mindec (result.dec, x.dec);
+result.dec = min (result.dec, x.dec);
 
 ## gammaln is continuous everywhere, but defined for x > 0 only
-result.dec (not (interior (x, infsupdec (0, inf)))) = "trv";
+result.dec (not (interior (x, infsupdec (0, inf)))) = _trv ();
 
 endfunction
 
