@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} {@var{x} =} gauss (@var{A}, @var{b})
 ## 
 ## Solve a linear interval system @var{A} * @var{x} = @var{b} using Gaussian
@@ -33,6 +33,7 @@
 ## @group
 ## gauss (infsupdec ([1, 0; 0, 2]), [2, 0; 0, 4])
 ##   @result{} 2×2 interval matrix
+##
 ##      [2]_trv   [0]_trv
 ##      [0]_trv   [2]_trv
 ## @end group
@@ -66,9 +67,7 @@ if (isnai (y))
     return
 endif
 
-result = newdec (gauss (intervalpart (x), intervalpart (y)));
-## Reverse operations should not carry decoration
-result.dec (:) = "trv";
+result = infsupdec (gauss (intervalpart (x), intervalpart (y)), "trv");
 
 endfunction
 
