@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} {} hypot (@var{X}, @var{Y})
 ## 
 ## Compute the euclidean norm.
@@ -60,7 +60,7 @@ endif
 
 result = newdec (hypot (intervalpart (x), intervalpart (y)));
 ## hypot is continuous and defined everywhere
-result.dec = mindec (result.dec, x.dec, y.dec);
+result.dec = min (result.dec, min (x.dec, y.dec));
 
 endfunction
 
