@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} isnai (@var{X})
 ## 
 ## Check if the interval is the result of a failed interval construction.
@@ -34,9 +34,7 @@ if (nargin ~= 1)
 endif
 
 ## NaI is internally stored as a scalar empty interval with ill decoration.
-## Therefore, we do not have to perform an expensive strcmp operation on large
-## matrices when it suffices to look at the number of elements.
-result = numel (interval.dec) == 1 && strcmp (interval.dec, "ill");
+result = isscalar (interval.dec) && interval.dec == _ill ();
 
 endfunction
 
