@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} log1p (@var{X})
 ## 
 ## Compute @code{log (1 + @var{X})} accurately in the neighborhood of zero.
@@ -49,10 +49,10 @@ if (isnai (x))
 endif
 
 result = newdec (log1p (intervalpart (x)));
-result.dec = mindec (result.dec, x.dec);
+result.dec = min (result.dec, x.dec);
 
 ## log1p is continuous everywhere, but defined for x > -1 only
-result.dec (not (interior (x, infsupdec (-1, inf)))) = "trv";
+result.dec (not (interior (x, infsupdec (-1, inf)))) = _trv ();
 
 endfunction
 
