@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} pow10 (@var{X})
 ## 
 ## Compute @code{10^x} for all numbers in @var{X}.
@@ -48,7 +48,7 @@ endif
 
 result = newdec (pow10 (intervalpart (x)));
 ## pow10 is defined and continuous everywhere
-result.dec = mindec (result.dec, x.dec);
+result.dec = min (result.dec, x.dec);
 
 endfunction
 
