@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} psi (@var{X})
 ## 
 ## Compute the digamma function, also known as the psi function.
@@ -64,12 +64,12 @@ endif
 
 result = newdec (psi (intervalpart (x)));
 ## psi is continuous where it is defined
-result.dec = mindec (result.dec, x.dec);
+result.dec = min (result.dec, x.dec);
 
 undefined = (inf (x) <= 0 & fix (inf (x)) == inf (x)) | ...
             (sup (x) <= 0 & fix (sup (x)) == sup (x)) | ...
             (inf (x) < 0 & ceil (inf (x)) <= floor (sup (x)));
-result.dec (undefined) = mindec (result.dec (undefined), "trv");
+result.dec (undefined) = _trv ();
 
 endfunction
 
