@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} sech (@var{X})
 ## 
 ## Compute the hyperbolic secant, that is the reciprocal hyperbolic cosine.
@@ -48,7 +48,7 @@ endif
 
 result = newdec (sech (intervalpart (x)));
 ## sech is defined and continuous everywhere
-result.dec = mindec (result.dec, x.dec);
+result.dec = min (result.dec, x.dec);
 
 endfunction
 
