@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} tan (@var{X})
 ## 
 ## Compute the tangent in radians.
@@ -47,12 +47,12 @@ if (isnai (x))
 endif
 
 result = newdec (tan (intervalpart (x)));
-result.dec = mindec (result.dec, x.dec);
+result.dec = min (result.dec, x.dec);
 
 ## Because tan (nextdown (pi / 2)) < realmax, we can simple check for
 ## a singularity by comparing the result with entire.
 domain = not (isentire (result));
-result.dec (not (domain)) = "trv";
+result.dec (not (domain)) = _trv ();
 
 endfunction
 
