@@ -14,7 +14,7 @@
 ## along with this program; if not, see <http://www.gnu.org/licenses/>.
 
 ## -*- texinfo -*-
-## @documentencoding utf-8
+## @documentencoding UTF-8
 ## @deftypefn {Function File} {} - @var{X}
 ## 
 ## Negate all numbers in the interval.
@@ -47,7 +47,8 @@ if (isnai (x))
 endif
 
 ## uminus is defined and continuous everywhere
-result = infsupdec (uminus (intervalpart (x)), x.dec);
+result = newdec (uminus (intervalpart (x)));
+result.dec = x.dec;
 
 endfunction
 
