@@ -154,17 +154,18 @@ std::pair <Matrix, Matrix> interval_matrix_mul (
 
 DEFUN_DLD (mpfr_matrix_mul_d, args, nargout, 
   "-*- texinfo -*-\n"
-  "@documentencoding utf-8\n"
-  "@deftypefn  {Loadable Function} {[@var{L}, @var{U}] = } mpfr_matrix_mul_d (@var{XL}, @var{YL}, @var{XU}, @var{YU})\n"
+  "@documentencoding UTF-8\n"
+  "@deftypefn  {Loadable Function} {[@var{L}, @var{U}] =} mpfr_matrix_mul_d (@var{XL}, @var{YL}, @var{XU}, @var{YU})\n"
   "\n"
-  "Compute the upper and lower boundary of the matrix multiplication of "
-  "interval matrices [@var{XL}, @var{XU}] and [@var{YL}, @var{YU}] in "
-  "binary64 numbers with tightest result."
+  "Compute the matrix product with binary64 numbers and correctly rounded "
+  "result."
   "\n\n"
-  "The result is guaranteed to be tightest / correctly rounded.  That is, the "
-  "function is evaluated with (virtually) infinite precision and the exact "
-  "result is approximated with a binary64 number using the desired rounding "
-  "direction."
+  "Compute the lower and upper boundary of the matrix multiplication of "
+  "interval matrices [@var{XL}, @var{XU}] and [@var{YL}, @var{YU}]."
+  "\n\n"
+  "The result is guaranteed to be tight.  That is, the matrix product is "
+  "evaluated with (virtually) infinite precision and the exact result is "
+  "approximated with binary64 numbers using directed rounding."
   "\n\n"
   "@example\n"
   "@group\n"
