@@ -21,27 +21,28 @@
 
 DEFUN_DLD (mpfr_vector_sum_d, args, nargout, 
   "-*- texinfo -*-\n"
-  "@documentencoding utf-8\n"
-  "@deftypefn  {Loadable Function} {[@var{S}, @var{E}] = } mpfr_vector_sum_d (@var{R}, @var{X})\n"
+  "@documentencoding UTF-8\n"
+  "@deftypefn  {Loadable Function} {[@var{S}, @var{E}] =} mpfr_vector_sum_d (@var{R}, @var{X})\n"
   "\n"
   "Compute the sum @var{S} of all numbers in a binary64 vector @var{X} with "
   "correctly rounded result."
   "\n\n"
-  "@var{R} is the rounding direction (0: towards zero, 0.5: towards nearest "
-  "and ties to even, +inf towards positive infinity, -inf towards negative "
-  "infinity)."
+  "@var{R} is the rounding direction (@option{0}: towards zero, @option{0.5}: "
+  "towards nearest and ties to even, @option{+inf}: towards positive "
+  "infinity, @option{-inf}: towards negative infinity)."
   "\n\n"
-  "The result is guaranteed to be correctly rounded.  That is, the function "
-  "is evaluated with (virtually) infinite precision and the exact result is "
+  "The result is guaranteed to be correctly rounded.  That is, the sum is "
+  "evaluated with (virtually) infinite precision and the exact result is "
   "approximated with a binary64 number using the desired rounding direction."
   "\n\n"
   "If one element of the vector is NaN or infinities of both signs are "
-  "encountered, the result will be NaN."
+  "encountered, the result will be NaN.  An @emph{exact} zero is returned as "
+  "+0 in all rounding directions, except for rounding towards negative "
+  "infinity, where -0 is returned."
   "\n\n"
-  "An exact(!) zero is returned as +0 in all rounding directions, except for "
-  "rounding towards negative infinity, where -0 is returned."
-  "\n\n"
-  "A second output parameter @var{E} yields an approximation of the error."
+  "A second output parameter yields an approximation of the error.  The "
+  "difference between the exact sum over @var{X} and @var{S} is approximated "
+  "by a second binary64 number @var{E} with rounding towards zero."
   "\n\n"
   "@example\n"
   "@group\n"
